require_relative 'city_methods'

module OpenWeatherMap

  class Weather
    include HTTParty
    extend CityMethods
    attr_reader :city, :city_id, :lat, :lng
    
    base_uri 'http://api.openweathermap.org/data/2.5'

    def initialize(args)
      @city = args[:city]
      @city_id = args[:city_id]
      @lat = args[:lat]
      @lng = args[:lng]
    end

    def forecast(options={})
      defaults = {
        daily: false,
        units: 'imperial',
        count: 16
      }
      options = defaults.merge(options)
      @forecast ||= get_forecast(options)
    end

    private

      def get_forecast(options)
        options[:daily] ? daily_forecast(options) : three_hour_forecast(options)
      end

      def daily_forecast(options)
        return self.class.get "/forecast/daily?id=#{city_id}&cnt=#{options[:count]}&units=#{options[:units]}" if city_id
        return self.class.get "/forecast/daily?q=#{city}&cnt=#{options[:count]}&units=#{options[:units]}" if city
        return self.class.get "/forecast/daily?lat=#{lat}&lon=#{lng}&cnt=#{options[:count]}&units=#{options[:units]}" if lat && lng
      end

      def three_hour_forecast(options)
        return self.class.get "/forecast?id=#{city_id}&units=#{options[:units]}" if city_id
        return self.class.get "/forecast?q=#{city}&units=#{options[:units]}" if city
        return self.class.get "/forecast?lat=#{lat}&lon=#{lng}&units=#{options[:units]}" if lat && lng
      end
  end
end